/* -*- Mode: C; tab-width: 8; indent-tabs-mode: nil; c-basic-offset: 8 -*- */
/***************************************************************************
 *
 * kit-test.h : PolicyKit test
 *
 * Copyright (C) 2007 David Zeuthen, <david@fubar.dk>
 *
 * Permission is hereby granted, free of charge, to any person
 * obtaining a copy of this software and associated documentation
 * files (the "Software"), to deal in the Software without
 * restriction, including without limitation the rights to use, copy,
 * modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be
 * included in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
 * HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
 * WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 *
 **************************************************************************/

#if !defined (KIT_COMPILATION) && !defined(_KIT_INSIDE_KIT_H)
#error "Only <kit/kit.h> can be included directly, this file may disappear or change contents."
#endif

#ifndef KIT_TEST_H
#define KIT_TEST_H

#include <kit/kit.h>

KIT_BEGIN_DECLS

/**
 * KitTest:
 * @name: name of the unit test
 * @setup: setup function
 * @teardown: teardown function
 * @run: actual test function.
 *
 * Test suite abstraction. See kit_test_run() for details.
 */
typedef struct {
        const char *name;
        void (*setup) (void);
        void (*teardown) (void);
        kit_bool_t (*run) (void);
} KitTest;

kit_bool_t kit_test_run (KitTest **tests, size_t num_tests);

extern KitTest _test_memory;
extern KitTest _test_string;
extern KitTest _test_hash;
extern KitTest _test_list;
extern KitTest _test_file;
extern KitTest _test_spawn;
extern KitTest _test_message;
extern KitTest _test_entity;

KIT_END_DECLS

#endif /* KIT_TEST_H */


